@@ -9,8 +9,8 @@ use File::Spec::Functions;
 $Data::Dumper::Sortkeys = 1;
 use File::Basename;
 
-$NBI::Job::VERSION           = $NBI::Slurm::VERSION;
-my $DEFAULT_QUEUE               = "nbi-short";
+$NBI::Job::VERSION  = $NBI::Slurm::VERSION;
+my $DEFAULT_QUEUE   = "nbi-short";
 require Exporter;
 our @ISA = qw(Exporter);
 
@@ -156,7 +156,7 @@ sub errorfile : lvalue {
 
     # Create a default error_file if not defined
     if (not defined $self->{error_file}) {
-        $self->{error_file} = catfile( $self->opts->tmpdir , $self->name . ".%j.out");
+        $self->{error_file} = catfile( $self->opts->tmpdir , $self->name . ".%j.err");
     }
     
     if ($interpolate) {
@@ -352,7 +352,7 @@ NBI::Job - A class for representing a job for NBI::Slurm
 
 =head1 VERSION
 
-version 0.8.0
+version 0.8.1
 
 =head1 SYNOPSIS
 
